aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--boot.php4
-rw-r--r--mod/settings.php6
2 files changed, 5 insertions, 5 deletions
diff --git a/boot.php b/boot.php
index 2553642fc..b02b0be98 100644
--- a/boot.php
+++ b/boot.php
@@ -422,9 +422,9 @@ class App {
}
function init_pagehead() {
- $interval = ((local_user()) ? get_pconfig(local_user(),'system','update_interval') : 30000);
+ $interval = ((local_user()) ? get_pconfig(local_user(),'system','update_interval') : 40000);
if($interval < 10000)
- $interval = 30000;
+ $interval = 40000;
$this->page['title'] = $this->config['sitename'];
$tpl = file_get_contents('view/head.tpl');
diff --git a/mod/settings.php b/mod/settings.php
index e88e50a05..18e2d8ae6 100644
--- a/mod/settings.php
+++ b/mod/settings.php
@@ -227,7 +227,7 @@ function settings_post(&$a) {
$browser_update = ((x($_POST,'browser_update')) ? intval($_POST['browser_update']) : 0);
$browser_update = $browser_update * 1000;
if($browser_update < 10000)
- $browser_update = 30000;
+ $browser_update = 40000;
$allow_location = (((x($_POST,'allow_location')) && (intval($_POST['allow_location']) == 1)) ? 1: 0);
@@ -625,8 +625,8 @@ function settings_content(&$a) {
$suggestme = get_pconfig(local_user(), 'system','suggestme');
$suggestme = (($suggestme===false)?0:$suggestme); // default if not set: 0
- $browser_update = get_pconfig(local_user(), 'system','update_interval');
- $browser_update = (($browser_update===false)? 30 : $browser_update / 1000); // default if not set: 30 seconds
+ $browser_update = intval(get_pconfig(local_user(), 'system','update_interval'));
+ $browser_update = (($browser_update===false)? 40 : $browser_update / 1000); // default if not set: 40 seconds
if(! strlen($a->user['timezone']))
$timezone = date_default_timezone_get();